// Enforce use of a strict operating context.
'use strict';

// Define handler for this plugin.
const plugin = (server, options, next) => {

  // Use app dependency container.
  const { container } = options;

  // Resolve dependencies from app container.
  container.resolve((peers, namespace) => {

    // Core dependencies required before trying to load this plugin.
    server.dependency(peers(__dirname), (server, next) => {

      // Register plugin controllers.
      const controllers = {
        admin: require('./controllers/admin')(server),
        api: require('./controllers/api')(server)
      };

      // Register plugin views.
      server.registerPluginViews(__dirname);

      // Register plugin views.
      server.registerPluginAssets(__dirname);

      // Attach plugin route(s) to admin server.
      server.select('admin').route([
        {
          method: 'GET',
          path: '/instance',
          config: {
            id: namespace.admin('index'),
            handler: controllers.admin.index
          }
        }
      ]);

      // Attach plugin route(s) to api server.
      server.select('api').route([
        {
          method: 'GET',
          path: '/instance',
          handler: controllers.api.get
        },
        {
          method: 'PUT',
          path: '/instance',
          handler: controllers.api.update
        }
      ]);

      // Dependencies are registered, continue with next callback.
      next();

    });

    // Plugin is registered, continue with next callback.
    next();

  });

};

// Attach plugin attributes.
plugin.attributes = {
  pkg: require('./package.json')
};

// Expose plugin on module's register property.
exports.register = plugin;
